package com.gic.haoban.manage.service.service.hm.impl;

import com.gic.commons.util.UniqueIdUtils;
import com.gic.haoban.manage.api.enums.WelcomeRelationStatusEnum;
import com.gic.haoban.manage.service.dao.mapper.TabHaobanWelcomeTemplateRelationMapper;
import com.gic.haoban.manage.service.entity.hm.TabHaobanWelcomeTemplateRelation;
import com.gic.haoban.manage.service.pojo.bo.hm.HmWelcomeRelationBO;
import com.gic.haoban.manage.service.pojo.bo.welcome.WelcomeDetailBO;
import com.gic.haoban.manage.service.service.WelcomeService;
import com.gic.haoban.manage.service.service.hm.HmWelComeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;

/**
 * @Author MUSI
 * @Date 2022/7/4 1:06 PM
 * @Description
 * @Version
 **/
@Component
public class HmWelComeServiceImpl implements HmWelComeService {

    @Autowired
    private TabHaobanWelcomeTemplateRelationMapper welcomeTemplateRelationMapper;

    @Autowired
    private WelcomeService welcomeService;

    /**
     * 根据 关联方的code 获取关联的欢迎语
     *
     * @param referId
     * @return
     */
    @Override
    public WelcomeDetailBO queryHmWelcomeWithReferId(String referId) {
        TabHaobanWelcomeTemplateRelation welcomeTemplateRelation = welcomeTemplateRelationMapper.queryWelTemplateRelation(null, referId, WelcomeRelationStatusEnum.ENABLE.getCode());
        if (welcomeTemplateRelation == null) {
            return null;
        }
        return welcomeService.getWelcome(welcomeTemplateRelation.getWelcomeId(), welcomeTemplateRelation.getEnterpriseId());
    }

    /**
     * 保存欢迎语引用关联关系
     *
     * @param hmWelcomeRelationBO
     * @return
     */
    @Override
    @Transactional(rollbackFor = RuntimeException.class)
    public Boolean saveHmWelcomeRelation(HmWelcomeRelationBO hmWelcomeRelationBO) {
        TabHaobanWelcomeTemplateRelation welcomeTemplateRelation = new TabHaobanWelcomeTemplateRelation();
        welcomeTemplateRelation.setRelationId(UniqueIdUtils.uniqueLong());
        welcomeTemplateRelation.setEnterpriseId(hmWelcomeRelationBO.getEnterpriseId());
        welcomeTemplateRelation.setWxEnterpriseId(hmWelcomeRelationBO.getWxEnterpriseId());
        welcomeTemplateRelation.setWelcomeId(hmWelcomeRelationBO.getWelcomeId());
        welcomeTemplateRelation.setReferId(hmWelcomeRelationBO.getReferId());
        welcomeTemplateRelation.setReferName(hmWelcomeRelationBO.getReferName());
        welcomeTemplateRelation.setType(hmWelcomeRelationBO.getType());
        welcomeTemplateRelation.setStatus(WelcomeRelationStatusEnum.ENABLE.getCode());
        welcomeTemplateRelation.setCreateTime(new Date());
        welcomeTemplateRelation.setUpdateTime(new Date());
        welcomeTemplateRelationMapper.insertSelective(welcomeTemplateRelation);
        return Boolean.TRUE;
    }

    /**
     * 删除关联关系
     * 此处事务 为了事务传播
     *
     * @param referId
     * @return
     */
    @Override
    @Transactional(rollbackFor = RuntimeException.class)
    public Boolean updateWelcomeRelationStatus(String referId, Integer status) {

        TabHaobanWelcomeTemplateRelation welcomeTemplateRelation = welcomeTemplateRelationMapper.queryWelTemplateRelation(null, referId, WelcomeRelationStatusEnum.ENABLE.getCode());
        if (welcomeTemplateRelation == null) {
            return Boolean.FALSE;
        }
        TabHaobanWelcomeTemplateRelation temp = new TabHaobanWelcomeTemplateRelation();
        temp.setRelationId(welcomeTemplateRelation.getRelationId());
        temp.setUpdateTime(new Date());
        temp.setStatus(status);
        welcomeTemplateRelationMapper.updateByPrimaryKeySelective(temp);
        return Boolean.TRUE;
    }
}
